@@ -1,4 +1,4 @@
-from logging import warn
+from warnings import warn
 import os
 from time import time
 import numpy as np
@@ -254,8 +254,7 @@ class Model:
                     warn(
                         "NaN values found in `pred_v`. Replacing with DummyRegressor() values (i.e. mean of training targets)."
                     )
-                    pred_v = np.nan_to_num(pred_v, nan=np.mean(y))
-                mae_v = mean_absolute_error(act_v, pred_v)
+                    pred_v = np.nan_to_num(pred_v)
                 mae_v = mean_absolute_error(act_v, pred_v)
                 self.optimizer.update_swa(mae_v)
                 minima.append(self.optimizer.minimum_found)
